@@ -1,17 +1,16 @@
 import datetime
 import json
+import re
 from typing import Union
 
 import requests
 from google.protobuf import timestamp_pb2
-from google.cloud import pubsub_v1, secretmanager, secretmanager_v1
+from google.cloud import pubsub_v1
 from google.cloud import tasks_v2
 from google.cloud import error_reporting
-
+from expressmoney import status
 
 report = error_reporting.Client()
-client = secretmanager.SecretManagerServiceClient()
-access_secret_version = secretmanager_v1.types.service.AccessSecretVersionRequest()
 
 
 class PubSub:
@@ -158,11 +157,11 @@ class Request:
                  project: str = 'expressmoney',
                  timeout: tuple = (30, 30),
                  ):
-        self.__project = project
+        self._project = project
         self.__service = service
         self.__path = path
         self.__access_token = access_token
-        self.__timeout = timeout
+        self._timeout = timeout
 
     def run(self, payload: dict = None, update: bool = False):
         """
@@ -173,12 +172,55 @@ class Request:
         """
         if update:
             response = requests.put(self._uri, json=payload if payload else {}, headers=self._headers,
-                                    timeout=self.__timeout)
+                                    timeout=self._timeout)
         elif payload:
-            response = requests.post(self._uri, json=payload, headers=self._headers, timeout=self.__timeout)
+            response = requests.post(self._uri, json=payload, headers=self._headers, timeout=self._timeout)
         else:
-            response = requests.get(self._uri, headers=self._headers, timeout=self.__timeout)
-        if response.status_code not in (200, 201):
+            response = requests.get(self._uri, headers=self._headers, timeout=self._timeout)
+        if not any((status.is_success(response.status_code), status.is_client_error(response.status_code))):
+            try:
+                raise Exception(f'{response.status_code}:{response.url}:{response.json()}')
+            except Exception:
+                raise Exception(f'{response.status_code}:{response.url}:{response.text}')
+        return response
+
+    def post_file(self, file, file_name: str, type_: int = 1, is_public=False):
+        """
+        Save file in Google Storage
+        Args:
+            file: BytesIO file
+            file_name: "name_file.pdf"
+            type_: 1 - other files. All types see in storage service
+            is_public: True - access to file without auth.
+
+        Returns:
+
+        """
+        if len(file_name.split('.')) == 0:
+            raise Exception('File name in format "name_file.pdf"')
+
+        name, ext = file_name.split('.')
+        name = f'{name}_{datetime.datetime.now().timestamp()}'
+        name = re.sub('[^0-9a-zA-Z_]', '', name)
+        new_file_name = f'{name}.{ext}'
+
+        if re.match('^_[0-9]{16}$', name):
+            raise Exception('File name incorrect. Example correct "name_file.pdf"')
+
+        data = {
+            'name': name,
+            'type': type_,
+            'is_public': is_public,
+
+        }
+        response = requests.post(
+            url=self._uri,
+            data=data,
+            files={"file": (new_file_name, file.file)},
+            headers=self._headers,
+            timeout=self._timeout
+        )
+        if not any((status.is_success(response.status_code), status.is_client_error(response.status_code))):
             try:
                 raise Exception(f'{response.status_code}:{response.url}:{response.json()}')
             except Exception:
@@ -188,7 +230,7 @@ class Request:
     @property
     def _uri(self):
         local_url = 'http://127.0.0.1:8000'
-        url = f'https://{self.__service}-dot-{self.__project}.appspot.com' if self.__service else local_url
+        url = f'https://{self.__service}-dot-{self._project}.appspot.com' if self.__service else local_url
         return f'{url}{self.__path}'
 
     @property
@@ -199,13 +241,3 @@ class Request:
 
     def _get_authorization(self) -> dict:
         return {'X-Forwarded-Authorization': f'Bearer {self.__access_token}'} if self.__access_token else {}
-
-    @property
-    def _aud(self):
-        secrets = {
-            'expressmoney': 'projects/1086735462412/secrets/IAP_CLIENT_ID/versions/1',
-            'expressmoney-dev': 'projects/13337168308/secrets/IAP_CLIENT_ID/versions/1',
-            'loans-russia': 'projects/70455559151/secrets/IAP_CLIENT_ID/versions/1',
-        }
-        access_secret_version.name = secrets.get(self.__project, None)
-        return client.access_secret_version(request=access_secret_version).payload.data.decode("utf-8")
